"use client";

import { useInView } from "react-intersection-observer";
import { useEffect } from "react";
import { School } from "@/types/school";
import SchoolCard from "./SchoolCard";
import { Alert, AlertDescription } from "@/components/ui/alert";

interface SearchResultsProps {
  schools: School[];
  isLoading: boolean;
  error: Error | null;
  hasNextPage: boolean;
  onLoadMore: () => void;
}

export default function SearchResults({
  schools,
  isLoading,
  error,
  hasNextPage,
  onLoadMore,
}: SearchResultsProps) {
  const { ref, inView } = useInView();

  useEffect(() => {
    if (inView && hasNextPage && !isLoading) {
      onLoadMore();
    }
  }, [inView, hasNextPage, isLoading, onLoadMore]);

  if (error) {
    return (
      <Alert variant="destructive">
        <AlertDescription>
          Failed to load schools. Please try again later.
        </AlertDescription>
      </Alert>
    );
  }

  return (
    <div className="space-y-6">
      {schools.map((school) => (
        <SchoolCard key={school.id} school={school} />
      ))}
      
      {hasNextPage && (
        <div ref={ref} className="w-full h-20 flex items-center justify-center">
          {isLoading && (
            <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-primary" />
          )}
        </div>
      )}

      {!hasNextPage && schools.length === 0 && !isLoading && (
        <div className="text-center py-12">
          <h3 className="text-lg font-semibold mb-2">No schools found</h3>
          <p className="text-muted-foreground">
            Try adjusting your search criteria
          </p>
        </div>
      )}
    </div>
  );
}